#include <ardour/curve.h>

#include "editor.h"
#include "region_gain_line.h"
#include "regionview.h"
#include "utils.h"

#include <ardour/session.h>

using namespace ARDOUR;

RegionGainLine::RegionGainLine (string name, Session& s, RegionView& r, Editor& e, GtkCanvasItem* parent,
				Curve& c, 
				gint (*point_callback)(GtkCanvasItem*, GdkEvent*, gpointer),
				gint (*line_callback)(GtkCanvasItem*, GdkEvent*, gpointer))
	: AutomationLineCurve (name, e, parent, c, point_callback, line_callback),
	  session (s),
	  rv (r)
{
	set_verbose_cursor_uses_gain_mapping (true);
	terminal_points_can_slide = false;
}

UndoAction
RegionGainLine::get_memento()
{
	return rv.region.get_memento();
}

void
RegionGainLine::view_to_model_y (double& y)
{
	y = slider_position_to_gain (y);
	y = max (0.0, y);
	y = min (2.0, y);
}

void
RegionGainLine::model_to_view_y (double& y)
{
	y = gain_to_slider_position (y);
}

void
RegionGainLine::change_model (unsigned long index, double x, double y)
{
	rv.region.modify_envelope_control_point (index, (jack_nframes_t) x, y);
}

void
RegionGainLine::change_model_range (unsigned long start, unsigned long end, double delta)
{
	rv.region.modify_envelope_control_points (start, end, delta);
}

void
RegionGainLine::remove_model_range (unsigned long start, unsigned long end)
{
	rv.region.remove_envelope_control_points (start, end);
}

void
RegionGainLine::add_to_model (double x, double y)
{
	rv.region.add_envelope_control_point ((jack_nframes_t) floor (x), y);
}
